<?php
/**
 * Admin setting class
 *
 * @author  MagniumThemes
 * @package magniumthemes.com
 */

if ( ! class_exists( 'mgupreloaderadmin' ) ) {
	/**
	 * Admin class.
	 * The class manage all the admin behaviors.
	 *
	 * @since 1.0.0
	 */
	class mgupreloaderadmin {

		public function __construct() {

			//Actions
			add_action( 'admin_init', array( $this, 'init' ) );
			add_action( 'admin_menu', array( $this, 'admin_page_setup' ));

			// Updates
			add_action( 'admin_notices', array( $this, 'mgtup_show_admin_notice_update') );
			add_action( 'admin_init', array( $this, 'mgtup_update_message_dismiss' ) );

			register_uninstall_hook( plugin_basename( __FILE__ ), array( 'mgupreloaderadmin', 'mgupreloader_uninstall' ) );

		}

		/**
		 * Init method:
		 *  - default options
		 *
		 * @access public
		 * @since  1.0.0
		 */
		public function init() {
			
			if ( isset( $_REQUEST['page'] ) && 'mgupreloader_settings' == $_REQUEST['page'] && is_admin()) {
				/* register plugin settings */
			
		        wp_enqueue_style( 'wp-color-picker' ); 
		        wp_enqueue_script( 'wp-color-picker' ); 
		        wp_enqueue_media();

			}
		}

		public function admin_page_setup() {

			add_options_page(esc_html__('Ultimate Preloader', 'mgupreloader'), esc_html__('Ultimate Preloader', 'mgupreloader'), 'manage_options', 'mgupreloader_settings', array( $this, 'mgupreloader_settings' ));

		}

		/**
		 * Register settings
		 *
		 * @return void
		 * @since 1.0.0
		 */
		public function mgupreloader_register_settings() {
			$mgupreloader_options_default = array(
				'enable' 		=> 0,
				'style'   		=> 'ball-8bits',
				'color'   		=> '#000000',
				'bg_color'		=> '#ffffff',
				'size'   		=> '',
				'image'   		=> 0,
				'image_url'   		=> '',
				'enable_gif'   		=> 0,
				'style_gif'   		=> 1,
				'size_gif'   		=> '64x64'
			);

			/* install the default plugin options */
            if ( ! get_option( 'mgupreloader_options' ) ){
                add_option( 'mgupreloader_options', $mgupreloader_options_default, '', 'yes' );
            }
		}

		static function mgupreloader_uninstall() {
			/* delete plugin options */
			delete_site_option( 'mgupreloader_options' );
			delete_option( 'mgupreloader_options' );
		}

		/**
		 * Print all plugin options.
		 *
		 * @return void
		 * @since 1.0.0
		 */
		public function mgupreloader_settings() {

			global $mgupreloader_styles_list, $mgupreloader_config;

			$this->mgupreloader_register_settings();
			
			$display_add_options = $message = $error = $result = '';

			$mgupreloader_options = get_option( 'mgupreloader_options' );
	                
			if ( isset( $_POST['mgupreloader_form_submit'] ) && check_admin_referer( plugin_basename( __FILE__ ), 'mgupreloader_nonce_name' ) ) {	
				/* Update settings */
				$mgupreloader_options['enable'] = isset( $_POST['enable'] ) ? sanitize_text_field($_POST['enable']) : '0';
				$mgupreloader_options['style'] = isset( $_POST['style'] ) ? sanitize_text_field($_POST['style']) : 'ball-8bits';
				$mgupreloader_options['color'] = isset( $_POST['color'] ) ? sanitize_text_field($_POST['color']) : '#000000';
				$mgupreloader_options['bg_color'] = isset( $_POST['bg_color'] ) ? sanitize_text_field($_POST['bg_color']) : '#ffffff';
				
				$mgupreloader_options['size'] = isset( $_POST['size'] ) ? sanitize_text_field($_POST['size']) : 'normal';
				$mgupreloader_options['image'] = isset( $_POST['image'] ) ? sanitize_text_field($_POST['image']) : '0';
				$mgupreloader_options['image_url'] = isset( $_POST['image_url'] ) ? sanitize_text_field($_POST['image_url']) : '';

				$mgupreloader_options['enable_gif'] = isset( $_POST['enable_gif'] ) ? sanitize_text_field($_POST['enable_gif']) : '0';
				$mgupreloader_options['style_gif'] = isset( $_POST['style_gif'] ) ? sanitize_text_field($_POST['style_gif']) : '1';
				$mgupreloader_options['size_gif'] = isset( $_POST['size_gif'] ) ? sanitize_text_field($_POST['size_gif']) : '64x64';
				
				/* Update settings in the database */
				if ( empty( $error ) ) {
					if($_POST['save_form'] == 1) {
						update_option( 'mgupreloader_options', $mgupreloader_options );
						$message .= esc_html__( "Settings saved.", 'mgupreloader' );
					} else {
						$message .= wp_kses_post(__( "Preview updated. <a class='settings-form-submit-save'>Save new settings</a> or <a href=''>revert back</a>?", 'mgupreloader' ));
					}
					
				}
				else {
					$error .= " " . esc_html__( "Settings are not saved.", 'mgupreloader' );
				}
			} 

			// All available preloader sizes with names
			$mgupreloader_size_list['sm'] = 'Small';
			$mgupreloader_size_list['normal'] = 'Normal';
			$mgupreloader_size_list['2x'] = 'Large';
			$mgupreloader_size_list['3x'] = 'Extra large';

			$mgupreloader_size_gif_list['32x32'] = 'Small';
			$mgupreloader_size_gif_list['64x64'] = 'Normal';
			$mgupreloader_size_gif_list['128x128'] = 'Large';

			// Build preloader preview
			$preloader_style = $mgupreloader_options['style'];
			$preloder_inline_html = $mgupreloader_styles_list[$preloader_style];

			if(($mgupreloader_options['image'] == 1) || ($mgupreloader_options['enable_gif'] == 1)) {
				if($mgupreloader_options['enable_gif'] == 1) {
					$preloader_inner_html = plugin_dir_url( __FILE__ ) . 'preloaders/gif/' . $mgupreloader_options['size_gif']. '/Preloader_' .$mgupreloader_options['style_gif'].'.gif';
					$preloader_html = '<div><img src="'.esc_url($preloader_inner_html).'" alt="'.esc_attr__( "Loading...", 'mgupreloader' ).'"/></div>';
				} else {
					$preloader_html = '<div><img src="'.esc_url($mgupreloader_options['image_url']).'" alt="'.esc_attr__( "Loading...", 'mgupreloader' ).'"/></div>';
				}
				
			} else {
				$preloader_html = '<div style="color: '.$mgupreloader_options['color'].'" class="la-'.$mgupreloader_options['style'].' la-'.$mgupreloader_options['size'].'">'.$preloder_inline_html.'</div>';
			}

			?>
			<div class="mgupreloader-settings wrap" id="mgupreloader-settings">
				<div id="icon-options-general" class="icon32 icon32-bws"></div>
				<h2><?php esc_html_e( "Ultimate WordPress Preloader", 'mgupreloader' ); ?></h2>
				<p>Thanks for using our plugin. If you get any problems or questions please <a href="http://support.magniumthemes.com/" target="_blank">let us know</a> and we will help you!</p>
				<a href="http://support.magniumthemes.com/" target="blank" class="button button-secondary">Get Premium support</a> <a href="http://themeforest.net/user/dedalx/portfolio/" target="blank" class="button button-secondary">Our Premium Themes</a> <a href="http://codecanyon.net/collections/5208381-premium-wordpress-plugins" target="blank" class="button button-secondary">Our other Ultimate Plugins</a> <a href="http://magniumthemes.com/how-to-rate-items-on-themeforest/" target="blank" class="button button-primary">Please Rate our plugin</a><br><br>
				<div class="updated fade" <?php if( empty( $message ) ) echo "style=\"display:none\""; ?>>
					<p><strong><?php echo $message; ?></strong></p>
				</div>
				<div class="error" <?php if ( empty( $error ) ) echo "style=\"display:none\""; ?>>
					<p><strong><?php echo $error; ?></strong></p>
				</div>
				<div id="mgupreloader-settings-notice" class="updated fade" style="display:none">
					<p><strong><?php esc_html_e( "Notice:", 'mgupreloader' ); ?></strong> <?php esc_html_e( "The plugin's settings have been changed. In order to save them please don't forget to click the 'Save Changes' button.", 'mgupreloader' ); ?></p>
				</div>
				<div class="preloader-two-column-wrapper clearfix">
				<div class="preloader-settings-column">
				
				<form id="mgupreloader_settings_form" method="post" action="">	
					<h3><?php esc_html_e( 'General settings', 'mgupreloader' ); ?></h3>
					<table class="form-table">
						<tr valign="top">
							<th scope="row"><?php esc_html_e( "Enable Preloader", 'mgupreloader' ); ?></th>
							<td>
								<?php if(isset($mgupreloader_options['enable']) && $mgupreloader_options['enable'] == 1) {
									$enable_preloader = ' checked';
								} else {
									$enable_preloader = '';
								}
								?>
								<label><input type="checkbox" name="enable" value="1"<?php echo esc_attr($enable_preloader); ?>/> 
								<span><?php esc_html_e( "Enable preloader on your site.", 'mgupreloader' ); ?></span></label>
						</td>
						</tr>
						<tr valign="top">
							<th scope="row"><?php esc_html_e( "Preloader background color", 'mgupreloader' ); ?></th>
							<td>
								<input type="text" name="bg_color" class="color-picker-field" value="<?php echo esc_attr($mgupreloader_options['bg_color']); ?>"/>
								
							</td>
						</tr>
					</table>
					<h3 id="form-table-css-preloaders"><?php esc_html_e( 'CSS3 Preloaders', 'mgupreloader' ); ?></h3>
					<input type="hidden" name="save_form" id="save_form" value="1"/>			
					<table class="form-table">
						
						<tr valign="top">
							<th scope="row"><?php esc_html_e( "CSS3 Preloader style", 'mgupreloader' ); ?></th>
							<td>
								
								<select name="style" id="mgtup_change_style">
								    <?php
								    $i = 0;
								    foreach ($mgupreloader_styles_list as $style => $inner_html) {
								    	if($style == $mgupreloader_options['style']) {
								    		$style_selected = ' selected';
								    	} else {
								    		$style_selected = '';
								    	}
								    	echo '<option data-id="'.esc_attr($i).'" value="'.$style.'"'.$style_selected.'>'.ucfirst(str_replace('-', ' ', $style)).'</option>';
								    	$i++;
								    }
								    ?>
							    </select><a class="button button-secondary link-smooth-scroll" href="#preloader-preview-styles"><?php esc_html_e( "Select from table", 'mgupreloader' ); ?></a><br/>
								<span  class="mgupreloader_info"><?php wp_kses_post(__( "Click 'Update preview' button after you changed style here.", 'mgupreloader' )); ?></span>
							</td>
						</tr>
						<tr valign="top">
							<th scope="row"><?php esc_html_e( "Preloader size", 'mgupreloader' ); ?></th>
							<td>
								
								<select name="size" id="mgtup_change_size">
								    <?php
								    foreach ($mgupreloader_size_list as $size => $size_name) {
								    	if($size == $mgupreloader_options['size']) {
								    		$size_selected = ' selected';
								    	} else {
								    		$size_selected = '';
								    	}
								    	echo '<option value="'.esc_attr($size).'"'.esc_attr($size_selected).'>'.esc_attr($size_name).'</option>';
								    }
								    ?>
							    </select>
							</td>
						</tr>
						<tr valign="top">
							<th scope="row"><?php esc_html_e( "CSS3 Preloader color", 'mgupreloader' ); ?></th>
							<td>
								<input type="text" name="color" class="color-picker-field" value="<?php echo esc_attr($mgupreloader_options['color']); ?>"/>
								
							</td>
						</tr>
						
						</table>
						<h3 id="form-table-gif-preloaders"><?php esc_html_e( 'GIF/Image Preloaders', 'mgupreloader' ); ?></h3>
						<table class="form-table">
						<tr valign="top">
							<th scope="row"><?php esc_html_e( "Use GIF preloader (disable CSS3 preloader)", 'mgupreloader' ); ?></th>
							<td>
								<?php if(isset($mgupreloader_options['enable_gif']) && $mgupreloader_options['enable_gif'] == 1) {
									$image_preloader = ' checked';
								} else {
									$image_preloader = '';
								}
								?>
								<label><input type="checkbox" name="enable_gif" value="1"<?php echo esc_attr($image_preloader); ?>/>
								<span><?php esc_html_e( "Replace CSS3 preloader with GIF image.", 'mgupreloader' ); ?></span></label>
							</td>
						</tr>
						<tr valign="top">
							<th scope="row"><?php esc_html_e( "GIF Preloader style", 'mgupreloader' ); ?></th>
							<td>
								<select name="style_gif" id="mgtup_change_gif_style">
								    <?php
								   
								    for($i=1;$i<=$mgupreloader_config['gif_preloader_count'];$i++) {
								    	if($i == $mgupreloader_options['style_gif']) {
								    		$style_selected = ' selected';
								    	} else {
								    		$style_selected = '';
								    	}
								    	echo '<option data-id="'.esc_attr($i).'" value="'.esc_attr($i).'"'.esc_attr($style_selected).'>Preloader '.esc_attr($i).'</option>';
								    }
								    ?>
							    </select><a class="button button-secondary link-smooth-scroll" href="#preloader-preview-styles-gif"><?php esc_html_e( "Select from table", 'mgupreloader' ); ?></a><br/>
								<span  class="mgupreloader_info"><?php esc_html_e( "Click 'Update preview' after you changed style here.", 'mgupreloader' ); ?></span>
							</td>
						</tr>
						<tr valign="top">
							<th scope="row"><?php esc_html_e( "Preloader GIF size", 'mgupreloader' ); ?></th>
							<td>
								
								<select name="size_gif" id="mgtup_change_gif_size">
								    <?php
								    foreach ($mgupreloader_size_gif_list as $size => $size_name) {
								    	if($size == $mgupreloader_options['size_gif']) {
								    		$size_selected = ' selected';
								    	} else {
								    		$size_selected = '';
								    	}
								    	echo '<option value="'.esc_attr($size).'"'.esc_attr($size_selected).'>'.esc_html($size_name).'</option>';
								    }
								    ?>
							    </select>
							</td>
						</tr>
						<tr valign="top">
							<th scope="row"><?php esc_html_e( "Use uploaded image (disable CSS3 or GIF preloaders)", 'mgupreloader' ); ?></th>
							<td>
								<?php if(isset($mgupreloader_options['image']) && $mgupreloader_options['image'] == 1) {
									$image_preloader = ' checked';
								} else {
									$image_preloader = '';
								}
								?>
								<label><input type="checkbox" name="image" value="1"<?php echo esc_attr($image_preloader); ?>/>
								<span><?php esc_html_e( "Replace preloader with your image.", 'mgupreloader' ); ?></span></label>
							</td>
						</tr>
						<tr valign="top">
							<th scope="row"><?php esc_html_e( "Preloader image url", 'mgupreloader' ); ?></th>
							<td>
								<input type="text" name="image_url" id="image_url" value="<?php echo esc_attr($mgupreloader_options['image_url']); ?>"/><input type="button" name="upload-btn" id="upload-btn" class="button-secondary" value="Upload Image">
								<br/><span  class="mgupreloader_info"><?php esc_html_e( "Full path to image that will be used in preloader instead of CSS3 animation.", 'mgupreloader' ); ?></span>
							</td>
						</tr>
						
					</table>
					<p class="submit">
						<input type="submit" id="settings-form-submit" class="button-primary" value="<?php esc_html_e( 'Save Changes', 'mgupreloader' ) ?>" />
						
						<input type="hidden" name="mgupreloader_form_submit" value="submit" />
						<?php wp_nonce_field( plugin_basename( __FILE__ ), 'mgupreloader_nonce_name' ); ?>
					</p>				
				</form>
				</div>
				<div class="preloader-preview-column">
				<h3><?php esc_html_e( 'Preloader preview', 'mgupreloader' ); ?></h3>
				<input type="submit" id="settings-form-submit-nosave" class="button-secondary" value="<?php esc_html_e( 'Update preview', 'mgupreloader' ) ?>" /> <input type="submit" id="settings-form-submit-save" class="button-primary settings-form-submit-save" value="<?php esc_html_e( 'Save Changes', 'mgupreloader' ) ?>" />
				<div class="preloader-preview-wrapper">

					<div class="mask-admin" style="background-color: <?php echo esc_attr($mgupreloader_options['bg_color']); ?>">
						<div id="mgtup-preloader">
						<?php echo wp_kses_post($preloader_html); ?>
						</div>
					</div>
				</div>
				</div>
				</div>
				<div class="clear"></div>
				<div id="preloader-preview-styles" class="preloader-preview-styles">
				<h3><?php esc_html_e( 'Preloader CSS3 styles table', 'mgupreloader' ); ?></h3>
				<p><?php esc_html_e( 'Click style that you like to select it in settings.', 'mgupreloader' ); ?></p>
				<div class="styles-table">
				<?php 
				$i = 0;
				foreach ($mgupreloader_styles_list as $style => $inner_html) {
					echo '<div class="preview-style-wrapper preview-style-css" data-id="'.esc_attr($i).'"><span>'.ucfirst(str_replace('-', ' ', esc_attr($style))).'</span><div class="preview-style-wrapper-inner"><div class="la-'.esc_attr($style).' la-dark">'.$inner_html.'</div></div></div>';
					$i++;
				}
				?>
				<div class="clear"></div>
				</div>
				</div>
				<br/>
				<a class="button button-secondary link-smooth-scroll" href="#mgupreloader-settings"><?php esc_html_e( "Back to settings", 'mgupreloader' ); ?></a>
				
				<div id="preloader-preview-styles-gif" class="preloader-preview-styles">
				<h3><?php esc_html_e( 'Preloader GIF styles table', 'mgupreloader' ); ?></h3>
				<p><?php esc_html_e( 'Click style that you like to select it in settings.', 'mgupreloader' ); ?></p>
				<div class="styles-table">
				<?php 
				for($i=1;$i<=$mgupreloader_config['gif_preloader_count'];$i++) {
			    	echo '<div class="preview-style-wrapper preview-style-gif" data-id="'.esc_attr($i).'"><span>Preloader '.esc_attr($i).'</span><div class="preview-style-wrapper-inner"><img src="'. plugin_dir_url( __FILE__ ) . 'preloaders/gif/64x64/Preloader_'.esc_attr($i).'.gif"/></div></div>';
			    }
				?>
				<div class="clear"></div>
				</div>
				</div>
				</div>
				<br/>
				<a class="button button-secondary link-smooth-scroll" href="#mgupreloader-settings"><?php esc_html_e( "Back to settings", 'mgupreloader' ); ?></a>

			</div>

			<?php
		}

		public function mgtup_show_admin_notice_update() {
			global $current_user;
			$user_id = $current_user->ID;

			if ( ! get_user_meta($user_id, 'mgtup_hind_update_message_ignore') && ( current_user_can( 'install_plugins' ) ) ):
		    ?>
		    <div class="updated below-h2">
				<a href="<?php echo esc_url( add_query_arg( 'mgtup_update_message_dismiss', '0' ) ); ?>" style="float: right;padding-top: 9px;">(never show this message again)&nbsp;&nbsp;<b>X</b></a><p style="display: inline-block;">Hi! Would you like to receive Ultimate WordPress Preloader updates news & get premium support? Subscribe to email notifications: </p>
				<form style="display: inline-block;" action="//magniumthemes.us8.list-manage.com/subscribe/post?u=6ff051d919df7a7fc1c84e4ad&amp;id=9285b358e7" method="post" id="mc-embedded-subscribe-form" name="mc-embedded-subscribe-form" class="validate" target="_blank" novalidate>
				   <input type="email" value="" name="EMAIL" class="required email" id="mce-EMAIL" placeholder="Your email">
				   <input type="submit" value="Subscribe" name="subscribe" id="mc-embedded-subscribe" class="button">
				</form>
		    </div>
		    <?php
			endif;
		}
		

		public function mgtup_update_message_dismiss() {
			global $current_user;
		    $user_id = $current_user->ID;
		    /* If user clicks to ignore the notice, add that to their user meta */
		    if ( isset($_GET['mgtup_update_message_dismiss']) && '0' == $_GET['mgtup_update_message_dismiss'] ) {
			    add_user_meta($user_id, 'mgtup_hind_update_message_ignore', 'true', true);
			}
		}

	}
}
